Class: Aws::MediaPackage::Types::HarvestJob

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-mediapackage/types.rb

Overview

A HarvestJob resource configuration

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#arnString

The Amazon Resource Name (ARN) assigned to the HarvestJob.



1103
1104
1105
1106
1107
1108
1109
1110
1111
1112
1113
1114
1115
# File 'lib/aws-sdk-mediapackage/types.rb', line 1103

class HarvestJob < Struct.new(
  :arn,
  :channel_id,
  :created_at,
  :end_time,
  :id,
  :origin_endpoint_id,
  :s3_destination,
  :start_time,
  :status)
  SENSITIVE = []
  include Aws::Structure
end

#channel_idString

The ID of the Channel that the HarvestJob will harvest from.



1103
1104
1105
1106
1107
1108
1109
1110
1111
1112
1113
1114
1115
# File 'lib/aws-sdk-mediapackage/types.rb', line 1103

class HarvestJob < Struct.new(
  :arn,
  :channel_id,
  :created_at,
  :end_time,
  :id,
  :origin_endpoint_id,
  :s3_destination,
  :start_time,
  :status)
  SENSITIVE = []
  include Aws::Structure
end

#created_atString

The date and time the HarvestJob was submitted.



1103
1104
1105
1106
1107
1108
1109
1110
1111
1112
1113
1114
1115
# File 'lib/aws-sdk-mediapackage/types.rb', line 1103

class HarvestJob < Struct.new(
  :arn,
  :channel_id,
  :created_at,
  :end_time,
  :id,
  :origin_endpoint_id,
  :s3_destination,
  :start_time,
  :status)
  SENSITIVE = []
  include Aws::Structure
end

#end_timeString

The end of the time-window which will be harvested.



1103
1104
1105
1106
1107
1108
1109
1110
1111
1112
1113
1114
1115
# File 'lib/aws-sdk-mediapackage/types.rb', line 1103

class HarvestJob < Struct.new(
  :arn,
  :channel_id,
  :created_at,
  :end_time,
  :id,
  :origin_endpoint_id,
  :s3_destination,
  :start_time,
  :status)
  SENSITIVE = []
  include Aws::Structure
end

#idString

The ID of the HarvestJob. The ID must be unique within the region and it cannot be changed after the HarvestJob is submitted.



1103
1104
1105
1106
1107
1108
1109
1110
1111
1112
1113
1114
1115
# File 'lib/aws-sdk-mediapackage/types.rb', line 1103

class HarvestJob < Struct.new(
  :arn,
  :channel_id,
  :created_at,
  :end_time,
  :id,
  :origin_endpoint_id,
  :s3_destination,
  :start_time,
  :status)
  SENSITIVE = []
  include Aws::Structure
end

#origin_endpoint_idString

The ID of the OriginEndpoint that the HarvestJob will harvest from. This cannot be changed after the HarvestJob is submitted.



1103
1104
1105
1106
1107
1108
1109
1110
1111
1112
1113
1114
1115
# File 'lib/aws-sdk-mediapackage/types.rb', line 1103

class HarvestJob < Struct.new(
  :arn,
  :channel_id,
  :created_at,
  :end_time,
  :id,
  :origin_endpoint_id,
  :s3_destination,
  :start_time,
  :status)
  SENSITIVE = []
  include Aws::Structure
end

#s3_destinationTypes::S3Destination

Configuration parameters for where in an S3 bucket to place the harvested content



1103
1104
1105
1106
1107
1108
1109
1110
1111
1112
1113
1114
1115
# File 'lib/aws-sdk-mediapackage/types.rb', line 1103

class HarvestJob < Struct.new(
  :arn,
  :channel_id,
  :created_at,
  :end_time,
  :id,
  :origin_endpoint_id,
  :s3_destination,
  :start_time,
  :status)
  SENSITIVE = []
  include Aws::Structure
end

#start_timeString

The start of the time-window which will be harvested.



1103
1104
1105
1106
1107
1108
1109
1110
1111
1112
1113
1114
1115
# File 'lib/aws-sdk-mediapackage/types.rb', line 1103

class HarvestJob < Struct.new(
  :arn,
  :channel_id,
  :created_at,
  :end_time,
  :id,
  :origin_endpoint_id,
  :s3_destination,
  :start_time,
  :status)
  SENSITIVE = []
  include Aws::Structure
end

#statusString

The current status of the HarvestJob. Consider setting up a CloudWatch Event to listen for HarvestJobs as they succeed or fail. In the event of failure, the CloudWatch Event will include an explanation of why the HarvestJob failed.



1103
1104
1105
1106
1107
1108
1109
1110
1111
1112
1113
1114
1115
# File 'lib/aws-sdk-mediapackage/types.rb', line 1103

class HarvestJob < Struct.new(
  :arn,
  :channel_id,
  :created_at,
  :end_time,
  :id,
  :origin_endpoint_id,
  :s3_destination,
  :start_time,
  :status)
  SENSITIVE = []
  include Aws::Structure
end